Filter a gtfs feed so that it only contains trips running on a given date
Source:R/filters.R
filter_feed_by_date.RdOnly stop_times, stops, routes, services (in calendar and calendar_dates), shapes, frequencies and transfers belonging to one of those trips are kept.
Usage
filter_feed_by_date(
gtfs_obj,
extract_date,
min_departure_time,
max_arrival_time,
include_parent_stations = FALSE
)Arguments
- gtfs_obj
gtfs feed (tidygtfs object)
- extract_date
date to extract trips from this day (Date or "YYYY-MM-DD" string)
- min_departure_time
(optional) The earliest departure time. Can be given as "HH:MM:SS", hms object or numeric value in seconds.
- max_arrival_time
(optional) The latest arrival time. Can be given as "HH:MM:SS", hms object or numeric value in seconds.
- include_parent_stations
whether to include stops refered in the parent_station column or not