Filter a gtfs feed so that it only contains trips that pass the given stops
Source:R/filters.R
filter_feed_by_stops.RdOnly stop_times, stops, routes, services (in calendar and calendar_dates), shapes, frequencies and transfers belonging to one of those trips are kept.
Usage
filter_feed_by_stops(
gtfs_obj,
stop_ids = NULL,
stop_names = NULL,
include_parent_stations = FALSE
)